@@ -208,6 +208,12 @@ public class CheckFingerprint extends CommandLineProgram {
             "ignoring RG annotations, and producing a single fingerprint metric for the entire BAM.")
     public boolean IGNORE_READ_GROUPS = false;
 
+    @Argument(doc = "When the expected fingerprint sample is not found in the genotypes file, this exit code is returned.")
+    public int EXIT_CODE_WHEN_EXPECTED_SAMPLE_NOT_FOUND = 1;
+
+    @Argument(doc = "When all LOD score are zero, exit with this value.")
+    public int EXIT_CODE_WHEN_NO_VALID_CHECKS = 2;
+
     private final Log log = Log.getInstance(CheckFingerprint.class);
 
     public static final String FINGERPRINT_SUMMARY_FILE_SUFFIX = "fingerprinting_summary_metrics";
@@ -242,71 +248,37 @@ public class CheckFingerprint extends CommandLineProgram {
 
         final FingerprintChecker checker = new FingerprintChecker(HAPLOTYPE_MAP);
         checker.setReferenceFasta(REFERENCE_SEQUENCE);
-        List<FingerprintResults> results;
 
-        String observedSampleAlias = null;
-        if (fileContainsReads(inputPath)) {
-            SequenceUtil.assertSequenceDictionariesEqual(SAMSequenceDictionaryExtractor.extractDictionary(inputPath), SAMSequenceDictionaryExtractor.extractDictionary(genotypesPath), true);
-            SequenceUtil.assertSequenceDictionariesEqual(SAMSequenceDictionaryExtractor.extractDictionary(inputPath), checker.getHeader().getSequenceDictionary(), true);
+        SequenceUtil.assertSequenceDictionariesEqual(SAMSequenceDictionaryExtractor.extractDictionary(inputPath), SAMSequenceDictionaryExtractor.extractDictionary(genotypesPath), true);
+        SequenceUtil.assertSequenceDictionariesEqual(SAMSequenceDictionaryExtractor.extractDictionary(inputPath), checker.getHeader().getSequenceDictionary(), true);
 
-            // Verify that there's only one sample in the SAM/BAM.
-            final SamReader in = SamReaderFactory.makeDefault().referenceSequence(REFERENCE_SEQUENCE).open(inputPath);
-            for (final SAMReadGroupRecord rec : in.getFileHeader().getReadGroups()) {
-                if (observedSampleAlias == null) {
-                    observedSampleAlias = rec.getSample();
-                } else if (!observedSampleAlias.equals(rec.getSample())) {
-                    throw new PicardException("inputPath SAM/BAM file must not contain data from multiple samples.");
-                }
-            }
-            CloserUtil.close(in);
 
-            // If expected sample alias isn't supplied, assume it's the one from the INPUT file's RGs
-            if (EXPECTED_SAMPLE_ALIAS == null) {
-                EXPECTED_SAMPLE_ALIAS = observedSampleAlias;
-            }
 
-            results = checker.checkFingerprints(
-                    Collections.singletonList(inputPath),
-                    Collections.singletonList(genotypesPath),
-                    EXPECTED_SAMPLE_ALIAS,
-                    IGNORE_READ_GROUPS);
-        } else {            // Input is a VCF
-            // Note that FingerprintChecker.loadFingerprints() verifies that the VCF's Sequence Dictionaries agree with that of the Haplotye Map File
+        final String observedSampleAlias = extractObservedSampleName(inputPath, OBSERVED_SAMPLE_ALIAS);
 
-            // Verify that there is only one sample in the VCF
-            final VCFFileReader fileReader = new VCFFileReader(inputPath, false);
-            final VCFHeader fileHeader = fileReader.getFileHeader();
-            if (fileHeader.getNGenotypeSamples() < 1) {
-                throw new PicardException("inputPath VCF file must contain at least one sample.");
-            }
-            if ((fileHeader.getNGenotypeSamples() > 1) && (OBSERVED_SAMPLE_ALIAS == null)) {
-                throw new PicardException("inputPath VCF file contains multiple samples and yet the OBSERVED_SAMPLE_ALIAS parameter is not set.");
-            }
-            // set observedSampleAlias to the parameter, if set.  Otherwise, if here, this must be a single sample VCF, get it's sample
-            observedSampleAlias = (OBSERVED_SAMPLE_ALIAS != null) ? OBSERVED_SAMPLE_ALIAS : fileHeader.getGenotypeSamples().get(0);
-
-            // Now verify that observedSampleAlias is, in fact, in the VCF
-            if (!fileHeader.getGenotypeSamples().contains(observedSampleAlias)) {
-                throw new PicardException("inputPath VCF file does not contain OBSERVED_SAMPLE_ALIAS: " + observedSampleAlias);
-            }
-
-            if (OBSERVED_SAMPLE_ALIAS == null) {
-                observedSampleAlias = fileHeader.getGenotypeSamples().get(0);
-            }
-            fileReader.close();
-
-            // If expected sample alias isn't supplied, assume it's the one from the INPUT file
-            if (EXPECTED_SAMPLE_ALIAS == null) {
-                EXPECTED_SAMPLE_ALIAS = observedSampleAlias;
-            }
-
-            results = checker.checkFingerprintsFromPaths(
-                    Collections.singletonList(inputPath),
-                    Collections.singletonList(genotypesPath),
-                    observedSampleAlias,
-                    EXPECTED_SAMPLE_ALIAS);
+        // If expected sample alias isn't supplied, assume it's the one from the INPUT file
+        if (EXPECTED_SAMPLE_ALIAS == null) {
+            EXPECTED_SAMPLE_ALIAS = observedSampleAlias;
         }
 
+        // check that EXPECTED_SAMPLE_ALIAS is in fingerprint vcf
+        if (!containsSample(genotypesPath, EXPECTED_SAMPLE_ALIAS)) {
+            log.warn("Sample " + EXPECTED_SAMPLE_ALIAS + " where fingerprint was expected not found in " + genotypesPath);
+            return EXIT_CODE_WHEN_EXPECTED_SAMPLE_NOT_FOUND;
+        }
+
+
+        final List<FingerprintResults> results = fileContainsReads(inputPath) ? checker.checkFingerprints(
+                Collections.singletonList(inputPath),
+                Collections.singletonList(genotypesPath),
+                EXPECTED_SAMPLE_ALIAS,
+                IGNORE_READ_GROUPS) :
+                checker.checkFingerprintsFromPaths(
+                        Collections.singletonList(inputPath),
+                        Collections.singletonList(genotypesPath),
+                        observedSampleAlias,
+                        EXPECTED_SAMPLE_ALIAS);
+
         final MetricsFile<FingerprintingSummaryMetrics, ?> summaryFile = getMetricsFile();
         final MetricsFile<FingerprintingDetailMetrics, ?> detailsFile = getMetricsFile();
 
@@ -376,7 +348,7 @@ public class CheckFingerprint extends CommandLineProgram {
             log.error("No non-zero results found. This is likely an error. " +
                     "Probable cause: EXPECTED_SAMPLE (if provided) or the sample name from INPUT (if EXPECTED_SAMPLE isn't provided)" +
                     "isn't a sample in GENOTYPES file.");
-            return 1;
+            return EXIT_CODE_WHEN_NO_VALID_CHECKS;
         }
 
         return 0;
@@ -408,4 +380,49 @@ public class CheckFingerprint extends CommandLineProgram {
                 p.toUri().getRawPath().endsWith(SamReader.Type.SAM_TYPE.fileExtension()) ||
                 p.toUri().getRawPath().endsWith(SamReader.Type.CRAM_TYPE.fileExtension()));
     }
+
+    static boolean containsSample(final Path p, final String sample) {
+        try (final VCFFileReader fileReader = new VCFFileReader(p, false)) {
+            final VCFHeader fileHeader = fileReader.getFileHeader();
+            return fileHeader.getGenotypeSamples().contains(sample);
+        }
+    }
+
+    static String extractObservedSampleName(final Path p, final String alias) {
+        String observedSampleAlias = null;
+        if (fileContainsReads(p)) {
+            // Verify that there's only one sample in the SAM/BAM.
+            try (final SamReader in = SamReaderFactory.makeDefault().open(p)) {
+                for (final SAMReadGroupRecord rec : in.getFileHeader().getReadGroups()) {
+                    if (observedSampleAlias == null) {
+                        observedSampleAlias = rec.getSample();
+                    } else if (!observedSampleAlias.equals(rec.getSample())) {
+                        throw new PicardException("inputPath SAM/BAM file must not contain data from multiple samples.");
+                    }
+                }
+            } catch (final IOException ex) {
+                throw new PicardException("Error reading " + p, ex);
+            }
+        } else {
+            try(final VCFFileReader fileReader = new VCFFileReader(p, false)) {
+
+                final VCFHeader fileHeader = fileReader.getFileHeader();
+                if (fileHeader.getNGenotypeSamples() < 1) {
+                    throw new PicardException("inputPath VCF file must contain at least one sample.");
+                }
+                if ((fileHeader.getNGenotypeSamples() > 1) && (alias == null)) {
+                    throw new PicardException("inputPath VCF file contains multiple samples and yet the OBSERVED_SAMPLE_ALIAS parameter is not set.");
+                }
+                // set observedSampleAlias to the parameter, if set.  Otherwise, if here, this must be a single sample VCF, get it's sample
+                observedSampleAlias = (alias != null) ? alias : fileHeader.getGenotypeSamples().get(0);
+
+                // Now verify that observedSampleAlias is, in fact, in the VCF
+                if (!fileHeader.getGenotypeSamples().contains(observedSampleAlias)) {
+                    throw new PicardException("inputPath VCF file does not contain OBSERVED_SAMPLE_ALIAS: " + observedSampleAlias);
+                }
+            }
+        }
+
+        return observedSampleAlias;
+    }
 }
