@@ -25,6 +25,7 @@ package picard.illumina.parser;
 
 import htsjdk.samtools.util.CloserUtil;
 import htsjdk.samtools.util.IOUtil;
+import org.apache.commons.lang.NotImplementedException;
 import picard.PicardException;
 import picard.illumina.parser.fakers.*;
 import picard.illumina.parser.readers.TileMetricsOutReader;
@@ -49,6 +50,7 @@ public class IlluminaFileUtil {
 
     public enum SupportedIlluminaFormat {
         Bcl,
+        Cbcl,
         Locs,
         Clocs,
         Pos,
@@ -116,6 +118,30 @@ public class IlluminaFileUtil {
                     }
                     utils.put(SupportedIlluminaFormat.Bcl, parameterizedFileUtil);
                     break;
+                case Cbcl:
+                    parameterizedFileUtil =  new ParameterizedFileUtil("L(//d+)_(//d+)", ".cbcl", basecallLaneDir, null, lane ) {
+                        @Override
+                        public boolean filesAvailable() {
+                            return IlluminaFileUtil.hasCbcls(basecallDir, lane);
+                        }
+
+                        @Override
+                        public List<String> verify(List<Integer> expectedTiles, int[] expectedCycles) {
+                            throw new NotImplementedException("`verify()` is not implemented for CBCLs");
+                        }
+
+                        @Override
+                        public List<String> fakeFiles(List<Integer> expectedTiles, int[] cycles, SupportedIlluminaFormat format) {
+                            throw new NotImplementedException("`fakeFiles()` is not implemented for CBCLs");
+                        }
+
+                        @Override
+                        public boolean checkTileCount() {
+                            return false;
+                        }
+                    };
+                    utils.put(SupportedIlluminaFormat.Cbcl, parameterizedFileUtil);
+                    break;
                 case Locs:
                     parameterizedFileUtil = new PerTileOrPerRunFileUtil(".locs", intensityLaneDir, new LocsFileFaker(), lane);
                     utils.put(SupportedIlluminaFormat.Locs, parameterizedFileUtil);
@@ -161,7 +187,7 @@ public class IlluminaFileUtil {
         //Used just to ensure predictable ordering
         final TreeSet<Integer> expectedTiles = new TreeSet<>();
 
-        final Iterator<TileMetricsOutReader.IlluminaTileMetrics> tileMetrics = new TileMetricsOutReader(tileMetricsOut, TileMetricsOutReader.TileMetricsVersion.TWO);
+        final Iterator<TileMetricsOutReader.IlluminaTileMetrics> tileMetrics = new TileMetricsOutReader(tileMetricsOut);
         while (tileMetrics.hasNext()) {
             final TileMetricsOutReader.IlluminaTileMetrics tileMetric = tileMetrics.next();
 
