@@ -40,6 +40,7 @@ import picard.illumina.parser.IlluminaDataType;
 import picard.illumina.parser.ReadData;
 import picard.illumina.parser.ReadStructure;
 import picard.illumina.parser.readers.BclQualityEvaluationStrategy;
+import picard.util.help.HelpConstants;
 
 import java.io.File;
 import java.util.*;
@@ -416,6 +417,7 @@ public class CollectHiSeqXPfFailMetrics extends CommandLineProgram {
     }
 
     /** a metric class for describing FP failing reads from an Illumina HiSeqX lane * */
+    @DocumentedFeature(groupName = HelpConstants.DOC_CAT_METRICS, summary = HelpConstants.DOC_CAT_METRICS_SUMMARY)
     public static class PFFailDetailedMetric extends MetricBase {
         /** The Tile that is described by this metric */
         public Integer TILE;
@@ -458,6 +460,7 @@ public class CollectHiSeqXPfFailMetrics extends CommandLineProgram {
      * Possible reasons are EMPTY (reads from empty wells with no template strand), POLYCLONAL (reads from wells that had more than one strand
      * cloned in them), MISALIGNED (reads from wells that are near the edge of the tile), UNKNOWN (reads that didn't pass PF but couldn't be diagnosed)
      */
+    @DocumentedFeature(groupName = HelpConstants.DOC_CAT_METRICS, summary = HelpConstants.DOC_CAT_METRICS_SUMMARY)
     public static class PFFailSummaryMetric extends MetricBase {
         /** The Tile that is described by this metric. Can be a string (like "All") to mean some marginal over tiles. * */
         public String TILE = null;
