@@ -94,7 +94,7 @@ public class CollectRnaSeqMetricsTest extends CommandLineProgramTest {
         };
         Assert.assertEquals(runPicardCommandLine(args), 0);
 
-        final MetricsFile<RnaSeqMetrics, Comparable<?>> output = new MetricsFile<RnaSeqMetrics, Comparable<?>>();
+        final MetricsFile<RnaSeqMetrics, Comparable<?>> output = new MetricsFile<>();
         output.read(new FileReader(metricsFile));
 
         final RnaSeqMetrics metrics = output.getMetrics().get(0);
@@ -382,6 +382,93 @@ public class CollectRnaSeqMetricsTest extends CommandLineProgramTest {
         Assert.assertEquals(metrics.PCT_R2_TRANSCRIPT_STRAND_READS, 0.333333);
     }
 
+    @DataProvider(name = "endBiasValues")
+    public static Object[][] endBiasValues() {
+        return new Object[][] {
+                // Case 1 - 25 nt in, ends should both be 0 coverage.
+                {
+                    25,
+                    0.0,
+                    0.0,
+                    0.0
+                },
+                // Case 2 - 50 nt in, 5' should be 0 coverage and 3' should be partially covered.
+                {
+                    50,
+                    1.543624,
+                    0.0,
+                    0.0
+                },
+                // Case 3 - 100 nt in, 3' and 5' should both have coverage.
+                {
+                    100,
+                    2.449664,
+                    1.677852,
+                    0.684932
+                }
+        };
+    }
+
+    @Test(dataProvider = "endBiasValues")
+    public void testBiasEndBiasAdjust(int end_bias_size, double expected_3prime, double expected_5prime, double expected_ratio) throws Exception {
+        final String sequence = "chr1";
+
+        // Create alignments that are shifted by a fixed distance from the 3' and 5' end of a transcript.
+        final SAMRecordSetBuilder builder = new SAMRecordSetBuilder(true, SAMFileHeader.SortOrder.coordinate);
+
+        // Set seed so that strandedness is consistent among runs.
+        builder.setRandomSeed(0);
+        final int sequenceIndex = builder.getHeader().getSequenceIndex(sequence);
+
+        final int read_length = 150;
+        final int n_fragments = 30;
+        final String read_cigar = read_length + "M";
+
+        final int txStart = 0;
+        final int txEnd = 1000;
+        final int five_prime_start = txStart + 51;
+        final int three_prime_start = txEnd - 25 - read_length;
+        final String refFlatStart = Integer.toString(txStart);
+        final String refFlatEnd = Integer.toString(txEnd);
+
+        for (int j=0; j < n_fragments; j++) {
+            builder.addPair("transcript_pair_" + j, sequenceIndex, five_prime_start, three_prime_start, false, false, read_cigar, read_cigar, false, true, -1);
+        }
+
+        final File samFile = File.createTempFile("tmp.collectRnaSeqMetrics.", ".sam");
+        samFile.deleteOnExit();
+
+        final SAMFileWriter samWriter = new SAMFileWriterFactory().makeSAMWriter(builder.getHeader(), false, samFile);
+        for (final SAMRecord rec: builder.getRecords()) samWriter.addAlignment(rec);
+        samWriter.close();
+
+        final File metricsFile = File.createTempFile("tmp.", ".rna_metrics");
+        metricsFile.deleteOnExit();
+
+        // Generate the metrics.
+        final RnaSeqMetrics metrics;
+        final MetricsFile<RnaSeqMetrics, Comparable<?>> output;
+
+        final String refFlatFile = getRefFlatFile(sequence, refFlatStart, refFlatEnd, refFlatStart, refFlatEnd, "1", refFlatStart, refFlatEnd).getAbsolutePath();
+
+        final String[] args = new String[] {
+                "INPUT=" +               samFile.getAbsolutePath(),
+                "OUTPUT=" +              metricsFile.getAbsolutePath(),
+                "REF_FLAT=" +            refFlatFile,
+                "STRAND_SPECIFICITY=" +     "NONE",
+                "END_BIAS_BASES=" +     end_bias_size
+        };
+        Assert.assertEquals(runPicardCommandLine(args), 0);
+
+        output = new MetricsFile<>();
+        output.read(new FileReader(metricsFile));
+        metrics = output.getMetrics().get(0);
+
+        Assert.assertEquals(metrics.MEDIAN_5PRIME_BIAS, expected_5prime);
+        Assert.assertEquals(metrics.MEDIAN_3PRIME_BIAS, expected_3prime);
+        Assert.assertEquals(metrics.MEDIAN_5PRIME_TO_3PRIME_BIAS, expected_ratio);
+    }
+
     @Test
     public void testPctRibosomalBases() throws Exception {
         final String sequence = "chr1";
@@ -399,6 +486,7 @@ public class CollectRnaSeqMetricsTest extends CommandLineProgramTest {
         builder.addFrag("ignoredFrag", builder.getHeader().getSequenceIndex(ignoredSequence), 1, false);
         final File samFile = File.createTempFile("tmp.collectRnaSeqMetrics.", ".sam");
         samFile.deleteOnExit();
+
         try (SAMFileWriter samWriter = new SAMFileWriterFactory().makeSAMWriter(builder.getHeader(), false, samFile)) {
             for (final SAMRecord rec : builder.getRecords()) {
                 samWriter.addAlignment(rec);
@@ -435,21 +523,21 @@ public class CollectRnaSeqMetricsTest extends CommandLineProgramTest {
         Assert.assertEquals(metrics.PCT_RIBOSOMAL_BASES, 0.4);
     }
 
-    public File getRefFlatFile(String sequence) throws Exception {
-        // Create a refFlat file with a single gene containing two exons, one of which is overlapped by the
-        // ribosomal interval.
+    public File getRefFlatFile(String sequence, String txStart, String txEnd, String cdsStart, String cdsEnd, String exonCount, String exonStarts, String exonEnds) throws Exception {
+        // Create a refFlat file containing a single gene with specified parameters.
+
         final String[] refFlatFields = new String[RefFlatColumns.values().length];
         refFlatFields[RefFlatColumns.GENE_NAME.ordinal()] = "myGene";
         refFlatFields[RefFlatColumns.TRANSCRIPT_NAME.ordinal()] = "myTranscript";
         refFlatFields[RefFlatColumns.CHROMOSOME.ordinal()] = sequence;
         refFlatFields[RefFlatColumns.STRAND.ordinal()] = "+";
-        refFlatFields[RefFlatColumns.TX_START.ordinal()] = "49";
-        refFlatFields[RefFlatColumns.TX_END.ordinal()] = "500";
-        refFlatFields[RefFlatColumns.CDS_START.ordinal()] = "74";
-        refFlatFields[RefFlatColumns.CDS_END.ordinal()] = "400";
-        refFlatFields[RefFlatColumns.EXON_COUNT.ordinal()] = "2";
-        refFlatFields[RefFlatColumns.EXON_STARTS.ordinal()] = "49,249";
-        refFlatFields[RefFlatColumns.EXON_ENDS.ordinal()] = "200,500";
+        refFlatFields[RefFlatColumns.TX_START.ordinal()] = txStart;
+        refFlatFields[RefFlatColumns.TX_END.ordinal()] = txEnd;
+        refFlatFields[RefFlatColumns.CDS_START.ordinal()] = cdsStart;
+        refFlatFields[RefFlatColumns.CDS_END.ordinal()] = cdsEnd;
+        refFlatFields[RefFlatColumns.EXON_COUNT.ordinal()] = exonCount;
+        refFlatFields[RefFlatColumns.EXON_STARTS.ordinal()] = exonStarts;
+        refFlatFields[RefFlatColumns.EXON_ENDS.ordinal()] = exonEnds;
 
         final File refFlatFile = File.createTempFile("tmp.", ".refFlat");
         refFlatFile.deleteOnExit();
@@ -459,4 +547,11 @@ public class CollectRnaSeqMetricsTest extends CommandLineProgramTest {
 
         return refFlatFile;
     }
+
+    public File getRefFlatFile(String sequence) throws Exception {
+        // Default refFlat file with a single gene containing two exons, one of which is overlapped by the
+        // ribosomal interval.
+
+        return getRefFlatFile(sequence, "49", "500", "74", "400", "2", "49,249", "200,500");
+    }
 }
