@@ -9,17 +9,8 @@ import org.testng.annotations.Test;
 import picard.PicardException;
 import picard.illumina.parser.IlluminaFileUtil.SupportedIlluminaFormat;
 
-import java.io.DataOutputStream;
-import java.io.File;
-import java.io.FileOutputStream;
-import java.io.IOException;
-import java.io.OutputStream;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collections;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Set;
+import java.io.*;
+import java.util.*;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
@@ -47,7 +38,7 @@ public class IlluminaFileUtilTest {
 
     @BeforeMethod
     private void setUp() throws Exception {
-        intensityDir = IOUtil.createTempDir("ift_test", "Intensities");
+        intensityDir = IOUtil.createTempDir("ift_test.Intensities").toFile();
         basecallDir = new File(intensityDir, "BaseCalls");
         if (!basecallDir.mkdir()) {
             throw new RuntimeException("Couldn't make basecalls dir " + basecallDir.getAbsolutePath());
@@ -274,9 +265,13 @@ public class IlluminaFileUtilTest {
     @Test(dataProvider = "missingTileFormats")
     public void missingTileTest(final int lane,
                                 final List<SupportedIlluminaFormat> formats,
-                                final List<SupportedIlluminaFormat> formatsToGetTiles,
+                                List<SupportedIlluminaFormat> formatsToGetTiles,
                                 final List<String> relativeFilesToDelete,
                                 final String compression) {
+
+        formatsToGetTiles = new LinkedList<>(formatsToGetTiles);
+        formatsToGetTiles.remove(SupportedIlluminaFormat.Cbcl);
+
         for (final SupportedIlluminaFormat format : formats) {
             makeFiles(format, intensityDir, lane, DEFAULT_TILES, DEFAULT_CYCLES, compression);
         }
@@ -516,6 +511,45 @@ public class IlluminaFileUtilTest {
         cfm.assertValid(DEFAULT_TILES, cycles);
     }
 
+    @Test(dataProvider = "testHasCbclsDataProvider")
+    public void testHasCbcls(final int lane,
+                             final boolean createCbclDir,
+                             final boolean createCbcl,
+                             final boolean expectedResult) throws IOException {
+
+        final File basecallsDir = IOUtil.createTempDir("basecalls").toFile();
+        basecallsDir.deleteOnExit();
+
+        if (0 < lane) {
+            final File laneDir = new File(basecallsDir, IlluminaFileUtil.longLaneStr(lane));
+            Assert.assertTrue(laneDir.mkdir());
+
+            if (createCbclDir) {
+                final File cbclDir = new File(laneDir, "C1.1");
+                cbclDir.mkdirs();
+                cbclDir.deleteOnExit();
+
+                if (createCbcl) {
+                    final File cbcl = new File(cbclDir, IlluminaFileUtil.longLaneStr(lane) + "_42.cbcl");
+                    new FileOutputStream(cbcl).close();
+                    cbcl.deleteOnExit();
+                }
+            }
+        }
+
+        Assert.assertEquals(IlluminaFileUtil.hasCbcls(basecallsDir, lane), expectedResult);
+    }
+
+    @DataProvider(name = "testHasCbclsDataProvider")
+    public Object[][] testHasCbclsDataProvider() {
+        return new Object[][]{
+                {1, true, true, true},    // lane directory, cbcl dir, and one cbcl
+                {1, true, false, false} , // lane directory, cbcl dir, but no cbcl
+                {1, false, false, false}, // lane directory, but neither cbcl dir nor cbcl
+                {-1, false, false, false} // no lane directory, cbcl dir, or cbcl
+        };
+    }
+
 
     public static void makeFiles(final SupportedIlluminaFormat format, final File intensityDir, final int lane,
                                  final List<Integer> tiles, final int[] cycles) {
